const buildState = ({ color }) => ({
	borderColor: color,
});

const field = (theme) => ({
	'.form-field-container': {
		marginBottom: '0',
		paddingTop: '.5rem',
		paddingBottom: '.25rem',
	},
	'.field': {
		'&-container': {
			position: 'relative',
			fontSize: '16px',
			display: 'flex',
			minHeight: '2rem',
			padding: '.75rem 0 .25rem .5rem',
			border: `1px solid ${theme('colors.gray.300')}`,
			borderRadius: theme('borderRadius.lg'),
			'&--info': buildState({ color: theme('colors.info.200') }),
			'&--success': buildState({ color: theme('colors.success.200') }),
			'&--warning': buildState({ color: theme('colors.warning.200') }),
			'&--error': buildState({ color: theme('colors.error.200') }),
			'&--multiline': {
				height: 'auto',
			},
			'&--nolabel': {
				border: 'none',
			},
		},
		'&-label': {
			color: theme('colors.gray.500'),
			backgroundColor: 'white',
			position: 'absolute',
			textTransform: 'uppercase',
			top: '-10px',
			left: '5px',
			fontSize: '12px',
			padding: '0 4px',
			fontWeight: 300,
			'& > svg': {
				fontSize: '1.2rem',
			},
			'&--disabled': {
				color: theme('colors.gray.200'),
			},
		},
		'&-input': {
			backgroundColor: 'white',
			outline: 'none',
			cursor: 'text',
			width: 'calc(100% - 0.75rem)',
			'&:read-only': {
				cursor: 'auto',
			},
			'&--multiline': {
				minHeight: '3rem',
			},
		},
	},
	'.checkbox-container, .radiobutton-container': {
		'.field-checkbox, .field-radio': {
			display: 'flex',
			alignItems: 'center',
			cursor: 'pointer',
			'& > svg': {
				color: theme('colors.primary.200'),
			},
			'&--disabled': {
				color: theme('colors.gray.100'),
				cursor: 'not-allowed',
				'& > svg': {
					color: theme('colors.gray.100'),
					cursor: 'not-allowed',
				},
			},
		},
		'.field-radiobutton': {
			display: 'flex',
			padding: '.25rem',
			alignItems: 'center',
			height: '100%',
			cursor: 'pointer',
			borderRadius: theme('borderRadius.lg'),
			border: `1px solid transparent`,
			'&--disabled': {
				color: theme('colors.gray.100'),
				cursor: 'not-allowed',
			},
			'&--active': {
				borderStyle: 'dashed',
				borderColor: theme('colors.primary.100'),
				backgroundColor: theme('colors.primary.50'),
			},
		},
	},
	'.field-validationMessage': {
		color: theme('colors.error.300'),
		marginLeft: '0.5rem',
		fontSize: '0.75rem',
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(field(theme));
};

module.exports.field = field;
