function hsl2hex({ h, s, l }) {
	const hDecimal = l / 100;
	const a = (s * Math.min(hDecimal, 1 - hDecimal)) / 100;
	const f = (n) => {
		const k = (n + h / 30) % 12;
		let color = hDecimal - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
		color = color <= 0 ? 0 : color;
		color = color >= 1 ? 1 : color;
		return Math.round(255 * Math.max(color, 0))
			.toString(16)
			.padStart(2, '0');
	};
	return `#${f(0)}${f(8)}${f(4)}`;
}

function dynamicHsl(h, s, l) {
	return ({ opVar, opVal }) => {
		if (opVal !== undefined) {
			return `hsla(${h}, ${s}, ${l}, ${opVal})`;
		}
		if (opVar !== undefined) {
			return `hsla(${h}, ${s}, ${l}, var(${opVar}, 1))`;
		}
		return `hsl(${h}, ${s}, ${l})`;
	};
}

const pallete = (color) => {
	const h = `var(--color-${color}-h)`;
	const s = `var(--color-${color}-s)`;
	const l = `var(--color-${color}-l)`;
	return {
		50: dynamicHsl(h, s, `calc(${l} + 30%)`),
		100: dynamicHsl(h, s, `calc(${l} + 20%)`),
		200: dynamicHsl(h, s, `calc(${l} + 10%)`),
		300: dynamicHsl(h, s, `calc(${l} + 0%)`),
		400: dynamicHsl(h, s, `calc(${l} - 10%)`),
		500: dynamicHsl(h, s, `calc(${l} - 20%)`),
	};
};

module.exports = {
	pallete,
	hsl2hex,
};
